#!/usr/bin/python
#-*- coding: utf-8 -*-

import ohtools
import matplotlib
from matplotlib import pyplot
import matplotlib.dates as dates
import datetime
import numpy
import sys
import pylab

params = {'legend.fontsize': 6	,
          'legend.linewidth': 1,
          'text.usetex': True}

pylab.rcParams.update(params)

font = {'family' : 'sarif',
        'size'   : 9}

pylab.rc('font', **font)

endyear = 2013
endmonth = 4
endday = 30

na_limit = 150

enddate = datetime.date(endyear, endmonth, endday)

datapath = '/Users/endre/Dropbox/Dokumenter/NTNU/10.semester/oh data/oh data/'



#importing signal:
signal_raw = ohtools.import_day_input()

try:
	nofscans = signal_raw.shape[0]
except AttributeError:
	print('Error in importing signal.')
	sys.exit()
	
start = 0
end = nofscans
nofres = end-start

q31 = numpy.zeros(nofres)
q42 = numpy.zeros(nofres)
na = numpy.zeros(nofres)
naohrat = numpy.zeros(nofres)
datevec = numpy.zeros(nofres, dtype=datetime.datetime)

start_date = datetime.date(int(signal_raw[0,0]), int(signal_raw[0,1]), int(signal_raw[0,2]))
end_date = datetime.date(int(signal_raw[-1,0]), int(signal_raw[-1,1]), int(signal_raw[-1,2]))

for i in range(nofres):
	scan = signal_raw[i+start,11:1035]
	q31[i], q42[i] = ohtools.qbranch(scan)
	na[i] = ohtools.sodiumlev(scan)
	naohrat[i] = na[i]/q42[i] 		
	datevec[i] = ohtools.get_time(signal_raw[i,:])
		
plthours = numpy.array([0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22])
fig1 = pyplot.figure(figsize = (4.5,3.3))
ax = fig1.add_subplot(211)
pyplot.title('OH (3-1) and (4-2) Q-branch intensities {} / {}'. \
		  format(start_date.strftime('%Y-%m-%d'), end_date.strftime('%Y-%m-%d')))
ax.plot_date(datevec, na/1000, 'k', label='Na')
ax.plot_date(datevec, q31/1000, 'r', label='Q (3,1)')
ax.plot_date(datevec, q42/1000, 'b', label='Q (4,2)')
pyplot.legend(['Na','Q(3-1)', 'Q(4-2)'])
ax.xaxis.set_major_locator( dates.HourLocator(plthours) )
ax.xaxis.set_major_formatter(dates.DateFormatter("%H:%M"))
pyplot.ylabel('Intensity [counts/sec]')

ax  = fig1.add_subplot(212)
ax.plot_date(datevec, naohrat, 'k')
pyplot.ylabel('Na-OH ratio')
ax.xaxis.set_major_formatter(dates.DateFormatter("%H:%M"))
ax.xaxis.set_major_locator( dates.HourLocator(plthours) )
pyplot.xlabel('Time [UTC]')


# pyplot.legend(loc='best')
pyplot.show()

