#!/usr/bin/python
#-*- coding: utf-8 -*-

import ohtools
import matplotlib
from matplotlib import pyplot as plt
import matplotlib.dates as dates
from datetime import datetime
import math
import warnings
import numpy
import sys

warnings.filterwarnings('ignore')

#importing signal:
signal_raw = ohtools.import_day_input()

NA_LIMIT = 1.5

filename_31 = ohtools.mkfilename(signal_raw)
resp_kr = numpy.loadtxt('ohtools/response_kr.dat')
numofsig = signal_raw.shape[0]
avgspec = ohtools.avgspec_nafilt(signal_raw, 25, numofsig-25, NA_LIMIT)
avgspec_kr = avgspec/resp_kr

peaks = ohtools.locate_peaks(avgspec_kr)

borders = ohtools.band_borders(peaks)
oh31pts = numpy.arange(borders[0], borders[1])
oh42pts = numpy.arange(borders[2], borders[3])
w_31, w_42 = ohtools.instrfunc_kr(peaks, borders)

#Indices on which to start and stop
START = 0
STOP = numofsig
TG = 200

avg31band = avgspec[oh31pts]
avg42band = avgspec[oh42pts]

#Calculating baseshapes from average spectrums
basepts31, basepts42 = ohtools.basepts(peaks)
baseshape_31 = ohtools.basecurve(avgspec, basepts31, borders[0], borders[1], 0)
baseshape_42 = ohtools.basecurve(avgspec, basepts42, borders[2], borders[3], 0)
baseshape_31 -= numpy.min(baseshape_31)
baseshape_42 -= numpy.min(baseshape_42)
avg31band -= baseshape_31
avg42band -= baseshape_42

#Computing temperatures of avarage spectrum
mt31, mmi31, mie31, mit31, ms31, err31 = ohtools.get_temp_subbg(avg31band, TG, w_31, 0, 1)
mt42, mmi42, mie42, mit42, ms42, err31 = ohtools.get_temp_subbg(avg42band, TG, w_42, 1, 1)

sig_indices = numpy.arange(START,STOP)
numofres =  len(sig_indices)

print('Filtering signals...')
signal_raw = ohtools.filtsig(signal_raw)
print('Done')

print('Calculating temperatures:')

filepath = '/Users/endre/Dropbox/Dokumenter/NTNU/10.semester/oh data/oh data singles/' + filename_31
f = open(filepath, 'w')

temps_31 = numpy.zeros(numofres)

k = 0
for i in sig_indices:
	
	if(k > 4 and k%5 == 0):
		TG_new = ohtools.mean(temps_31[k-5:k])
		if(math.isnan(TG_new) != True):
			TG = TG_new
							
	current_sig = signal_raw[i,11:1035]
	q31, q42 = ohtools.qbranch(current_sig)
	na = ohtools.sodiumlev(current_sig)

	try:
		naohratio = na/q42
	except ZeroDivisionError:
		naohratio = float('nan')

	current_band_31 = current_sig[oh31pts]-baseshape_31
	current_band_42 = current_sig[oh42pts]-baseshape_42
	
	time = ohtools.get_time(signal_raw[i,:])


	if naohratio < NA_LIMIT:

		if i < 25 or i > numofsig-25:

			t31, et31, i31, ei31, it31, err31 = ohtools.get_temp_fitbg(current_band_31, TG, w_31, 0, 0, baseshape_31)
			t42, et42, i42, ei42, it42, err42 = ohtools.get_temp_fitbg(current_band_42, TG, w_42, 1, 0, baseshape_42)

		else:

			t31, et31, i31, ei31, it31, err31 = ohtools.get_temp_subbg(current_band_31, TG, w_31, 0, 0)
			t42, et42, i42, ei42, it42, err42 = ohtools.get_temp_subbg(current_band_42, TG, w_42, 1, 0)
	
	else:
		t31 = float('nan')
		et31 = float('nan')
		i31 = float('nan')
		ei31 = float('nan') 
		ri31 = float('nan')
		it31 = 0
		err31 = 'High Na-OH ratio'

		t42 = float('nan')
		et42 = float('nan') 
		i42 = float('nan')  
		ei42 = float('nan')
		ri42 = float('nan')
		it42 = 0
		err42 = ''


	temps_31[k] = t31
	# temps_err_31[k] = et31
	# intens_31[k] = i31
	# intens_err_31[k] = ei31
	# real_intens_31[k] = ri31
	
	# temps_42[k] = t42
	# temps_err_42[k] = et42
	# intens_42[k] = i42
	# intens_err_42[k] = ei42
	# real_intens_31[k] = ri42
	

	ohtools.print_scan_result(k+1, numofres, t31, et31, i31, ei31, it31, t42, et42, i42, ei42, it42, na, naohratio, time, err31, err42)
	ohtools.write_scan_result(t31, et31, i31, ei31, t42, et42, i42, ei42, q31, q42, na, time, f)
	
	k += 1

f.close()

print('Iterations complete.')
a = ohtools.get_ohstats(filepath, 1)
print('Filename: {}'.format(filename_31))