import sys
import scipy.io
import numpy
from datetime import datetime
from datetime import date
from matplotlib import pyplot
import ohtools

rescurve = numpy.loadtxt('ohtools/response_kr.dat')

def getsig_abg(daymat):
	
	print('Extracting signal...')
	
	numofscans = daymat.shape[0]
	nsig = 0
	nds = 0
	#Counting number of signals and the backgrounds
	for i in range(numofscans):
		if(daymat[i,9] == 1):
			nsig += 1
		else:
			nds += 1
	
	#Finding average dark signal:		
	darksig = numpy.zeros((nds,1024))
	k = 0
	for i in range(numofscans):
		if(daymat[i,9] == 0): 
			darksig[k,:] = daymat[i,11:1035]
			k += 1

	avgds = numpy.zeros(1024)
	for i in range(1024):
		avgds[i] = numpy.sum(darksig[:,i])/nds

	fp = ohtools.highpass_vec(avgds) #The fixed pattern

	signal = numpy.zeros((nsig,1035))
	
	k = 0 #Index to store signals

	for i in range(numofscans):
		if(i == 0 and daymat[0,9] == 1): #If the first scan is not a background, take the first background for the first scans
			n = 1
			while(daymat[n,9] == 1):
				n += 1
				if(n == numofscans-1):
					print('Error in datafile. No backgrounds.')
					return 0
			ds = ohtools.lowpass_vec(daymat[n,11:1035])+fp #Finding the dark signal
		elif(daymat[i,9] == 0 and i < numofscans-1):
			n = i+1
			while(daymat[n,9] == 1 and n != numofscans-1): #Finding next background. If it the last scan is not a background, take the last.
				n += 1
				if(n == numofscans-1 and daymat[n,9] == 1):
					n = i
					break
			ds = ohtools.lowpass_vec(0.5*(daymat[i,11:1035]+daymat[n,11:1035]))+fp #Taking average of two backgrounds
		elif(i == numofscans-1 and daymat[i,9] == 0): #If last is background, do nothing.
			pass
		else:
			signal[k,0:10] = daymat[i,0:10]
			signal[k,11:1035] = (daymat[i,11:1035]-ds)/(daymat[i,6]*daymat[i,7]) #Subtracting dark signal, converting to counts/sec
			k += 1

	successflag = 1 #Flag to check that there is no backgrounds in the signal matrix
	
	for i in range(nsig):
		if(signal[i,9] == 0):
			successflag = 0
			break

	if(successflag == 0):
		print('Signal extraction not successful. Chech data file.')
		print("Bad signal at: " , i)
		return 0
		# sys.exit()
	else:
		print("Signal extraction successful")
		print("Number of signals: ", nsig)
		print('Number of backgrounds: ', nds)
			
	return signal
			
	
def import_day(year, day):

	daystr = ''

	if(day < 10):
		daystr += "00" + str(day)
	elif(day < 100):
		daystr += "0" + str(day)
	else:
		daystr = str(day)
	
	data_path = '/Users/endre/Dropbox/Dokumenter/NTNU/10.semester/spectrometer data/'

	try:
		data = scipy.io.loadmat(data_path + str(year) + "-" + daystr + ".mat")
		keys = list(data.keys())
		var_name = keys[2]
		if(var_name != 'daymat'):
			print('Import error: Not a daymat file')
			#sys.exit()
			return 0
	except IOError:
		print('Import error: Could not find file')
		#sys.exit()
		return 0

	daymat = data[var_name]
	start_date = date(int(daymat[0,0]), int(daymat[0,1]), int(daymat[0,2]))
	end_date = date(int(daymat[-1,0]), int(daymat[-1,1]), int(daymat[-1,2]))
	
	print("Data for ",start_date.strftime("%Y-%m-%d")," / ",
		  end_date.strftime("%Y-%m-%d")," loaded.")
	
	signal = getsig_abg(daymat)
	
	return signal		 

def import_day_input():
	
	year = input("Enter year: ")
	day = input("Enter daynumber: ")

	signal = import_day(int(year), int(day))

	return signal

				 	
def raw2kR(rawsig):
	#RAW2KR: Divides every signal in a raw signal matrix with the response curve.
	
	numofsigs = rawsig.shape[0]
	signal_kr = numpy.zeros((numofsigs,1035))
	for i in range(numofsigs):
		signal_kr[i,0:10] = rawsig[i,0:10]
		signal_kr[i,11:1035] = rawsig[i,11:1035]/rescurve
	
	return signal_kr
	
def get_time(scan):
	#get_time: returns a python datetime object from a single scan
	
	#Converting millisec to seconds and microseconds
	sec = scan[5]/1000
	nsec = int(sec)
	
	return datetime(int(scan[0]), int(scan[1]), int(scan[2]), int(scan[3]), int(scan[4]), 
					nsec)	

def mkfilename(signal):
	
	if(signal[0,1] < 10):
		month = "0" + str(int(signal[0,1]))
	else:
		month = str(int(signal[0,1]))
	
	if(signal[0,2] < 10):
		start_day = "0" + str(int(signal[0,2]))
	else:
		start_day = str(int(signal[0,2]))
	
	if(signal[-1,2] < 10):
		end_day = "0" + str(int(signal[-1,2]))
	else:
		end_day = str(int(signal[-1,2]))
	
	return "OH" + str(int(signal[0,0])) + "_" + month + "_" + start_day + end_day


def set_hpflag():
	#SET_HPFLAG: Returning 0 or 1 to set the highpass filter flag.
	hpflag = int(2)
	while(True):
		hpflag = int(input('Highpass (0/1): '))
		if(hpflag == 0 or hpflag == 1):
			break
		else:
			print('Wrong input. Type 0 or 1.')
	
	return hpflag